@@ -1,18 +1,21 @@
-from peek_core_device._private.storage.DeviceUpdateTuple import DeviceUpdateTuple
-from vortex.Tuple import Tuple, addTupleType, TupleField
+from vortex.Tuple import TupleField
+from vortex.Tuple import addTupleType
+from vortex.TupleAction import TupleActionABC
 
 from peek_core_device._private.PluginNames import deviceTuplePrefix
-from vortex.TupleAction import TupleActionABC
+from peek_core_device._private.storage.DeviceUpdateTuple import \
+    DeviceUpdateTuple
 
 
 @addTupleType
 class CreateDeviceUpdateAction(TupleActionABC):
-    """ Create Update Action
+    """Create Update Action
 
     Create a new device update entry, this will be accompanied by an upload.
 
     """
-    __tupleType__ = deviceTuplePrefix + 'CreateDeviceUpdateAction'
+
+    __tupleType__ = deviceTuplePrefix + "CreateDeviceUpdateAction"
 
     #:  Description of date1
-    newUpdate:DeviceUpdateTuple = TupleField()
\ No newline at end of file
+    newUpdate: DeviceUpdateTuple = TupleField()
